
#' Grep for column names from a \code{data.frame}
#'
#'
#'
#' @param pattern passed to \code{\link[base]{grep}}
#' @param x data.frame to work with
#' @param ... force later arguments to be passed by name
#' @param ignore.case passed to \code{\link[base]{grep}}
#' @param perl passed to \code{\link[base]{grep}}
#' @param value passed to \code{\link[base]{grep}}
#' @param fixed passed to \code{\link[base]{grep}}
#' @param useBytes passed to \code{\link[base]{grep}}
#' @param invert passed to \code{\link[base]{grep}}
#' @return column names of x matching grep condition.
#'
#' @examples
#'
#'
#' d <- data.frame(xa=1, yb=2)
#'
#' # starts with
#' grepdf('^x', d)
#'
#' # ends with
#' grepdf('b$', d)
#'
#' # very useful in pipelines
#' suppressPackageStartupMessages(library("dplyr"))
#' d2 <- data.frame(x = 1, val1 = 1, val2 = 2)
#' d2 %>%
#'   moveValuesToRows(. ,
#'                    nameForNewKeyColumn = 'measureName',
#'                    nameForNewValueColumn = 'measureValue',
#'                    columnsToTakeFrom = grepdf('^val', .))
#'
#' @export
#'
grepdf <- function(pattern, x,
                   ...,
                   ignore.case = FALSE, perl = FALSE, value = FALSE,
                   fixed = FALSE, useBytes = FALSE, invert = FALSE ) {
  if(length(list(...))>0) {
    stop("cdata::grepdf unexpected arguments")
  }
  nms <- colnames(x)
  nms[base::grep(pattern, nms,
                 ignore.case = ignore.case, perl = perl, value = value,
                 fixed = fixed, useBytes = useBytes, invert = invert)]
}
